==> jc-1.4.0.tar.gz: soot/toolkits/scalar/FlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.FlowAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowAnalysis

#include "soot/toolkits/scalar/AbstractFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_FlowAnalysis_H_
#define _JC_soot_toolkits_scalar_FlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_FlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$refs	_jc_soot_toolkits_scalar_FlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_FlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$object	_jc_soot_toolkits_scalar_FlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vmethods	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vtable	_jc_soot_toolkits_scalar_FlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vtype	_jc_soot_toolkits_scalar_FlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_FlowAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_FlowAnalysis$method$getFlowAfter$56e80e677f287a8d(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_FlowAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_toolkits_scalar_FlowAnalysis$method_info$getFlowAfter$56e80e677f287a8d;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FlowAnalysis$vmethods {
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getFlowAfter$56e80e677f287a8d)(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_FlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_FlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs {
	struct _jc_object	*unitToAfterFlow;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FlowAnalysis$refs {
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FlowAnalysis$object {
	_jc_soot_toolkits_scalar_FlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_FlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FlowAnalysis$vtype _jc_soot_toolkits_scalar_FlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_FlowAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/FlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.FlowAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowAnalysis

#include "soot/toolkits/scalar/AbstractFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_FlowAnalysis_H_
#define _JC_soot_toolkits_scalar_FlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_FlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$refs	_jc_soot_toolkits_scalar_FlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_FlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_FlowAnalysis$object	_jc_soot_toolkits_scalar_FlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vmethods	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vtable	_jc_soot_toolkits_scalar_FlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_FlowAnalysis$vtype	_jc_soot_toolkits_scalar_FlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_FlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_FlowAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_FlowAnalysis$method$getFlowAfter$56e80e677f287a8d(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_FlowAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_toolkits_scalar_FlowAnalysis$method_info$getFlowAfter$56e80e677f287a8d;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_FlowAnalysis$vmethods {
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getFlowAfter$56e80e677f287a8d)(_jc_env *, struct _jc_soot_toolkits_scalar_FlowAnalysis$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_FlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_FlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_FlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs {
	struct _jc_object	*unitToAfterFlow;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_FlowAnalysis$refs {
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_FlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_FlowAnalysis$object {
	_jc_soot_toolkits_scalar_FlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_FlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_FlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_FlowAnalysis$vtype _jc_soot_toolkits_scalar_FlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_FlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_FlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_FlowAnalysis_H_ */
